# cmfn

[![PyPI - Version](https://img.shields.io/pypi/v/cmfn.svg)](https://pypi.org/project/cmfn)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cmfn.svg)](https://pypi.org/project/cmfn)

-----


A collection of handy functions.

## Table of Contents

- [cmfn](#cmfn)
  - [Table of Contents](#table-of-contents)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install cmfn
```

## License

`cmfn` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
